class Statistics
  attr_reader :user

  def initialize(user)
    @user = user
  end

  def total_plays
    Activity.where(user: user).count
  end

  def activity_by_day
    start_date = 1.year.ago.to_date
    end_date = Date.today
    activities = Activity.where(user: user, created_at: start_date.beginning_of_day..end_date.end_of_day)
    activities.group("DATE(created_at)").count.transform_keys { |d| d.to_s }
  end

  def top_artists_all_time
    Activity.where(user: user)
      .group(:item_title).order("count_id DESC").limit(5).count(:id)
  end

  def top_artists_year
    year_start = Date.today.beginning_of_year
    Activity.where(user: user, created_at: year_start..Date.today.end_of_day)
      .group(:item_title).order("count_id DESC").limit(5).count(:id)
  end

  def top_artists_upcoming
    upcoming_start = 30.days.ago.to_date
    upcoming_end = Date.today
    Activity.where(user: user, started_at: upcoming_start.beginning_of_day..upcoming_end.end_of_day)
      .group(:item_title).order("count_id DESC").limit(5).count(:id)
  end

  def since_date
    Activity.where(user: user).order(:created_at).limit(1).pick(:created_at)
  end
end
